@@ -190,7 +190,7 @@ class PartitionsView(BaseTableView, DataTypeReader, VacuumSettings):
             {'get': 'properties', 'delete': 'delete', 'put': 'update'},
             {'get': 'list', 'post': 'create'}
         ],
-        'delete': [{'delete': 'delete'}],
+        'delete': [{'delete': 'delete'}, {'delete': 'delete'}],
         'nodes': [{'get': 'nodes'}, {'get': 'nodes'}],
         'children': [{'get': 'children'}],
         'sql': [{'get': 'sql'}],
@@ -591,7 +591,7 @@ class PartitionsView(BaseTableView, DataTypeReader, VacuumSettings):
             return internal_server_error(errormsg=str(e))
 
     @BaseTableView.check_precondition
-    def delete(self, gid, sid, did, scid, tid, ptid):
+    def delete(self, gid, sid, did, scid, tid, ptid=None):
         """
         This function will delete the table object
 
@@ -601,31 +601,47 @@ class PartitionsView(BaseTableView, DataTypeReader, VacuumSettings):
            did: Database ID
            scid: Schema ID
            tid: Table ID
+           ptid: Partition Table ID
         """
+        if ptid is None:
+            data = request.form if request.form else json.loads(
+                request.data, encoding='utf-8'
+            )
+        else:
+            data = {'ids': [ptid]}
 
         try:
-            SQL = render_template(
-                "/".join([self.partition_template_path, 'properties.sql']),
-                did=did, scid=scid, tid=tid, ptid=ptid,
-                datlastsysoid=self.datlastsysoid
-            )
-            status, res = self.conn.execute_dict(SQL)
-            if not status:
-                return internal_server_error(errormsg=res)
-
-            if not res['rows']:
-                return make_json_response(
-                    success=0,
-                    errormsg=gettext(
-                        'Error: Object not found.'
-                    ),
-                    info=gettext(
-                        'The specified partition could not be found.\n'
-                    )
+            for ptid in data['ids']:
+                SQL = render_template(
+                    "/".join([self.partition_template_path, 'properties.sql']),
+                    did=did, scid=scid, tid=tid, ptid=ptid,
+                    datlastsysoid=self.datlastsysoid
                 )
+                status, res = self.conn.execute_dict(SQL)
+                if not status:
+                    return internal_server_error(errormsg=res)
 
-            return super(PartitionsView, self).delete(
-                gid, sid, did, scid, tid, res)
+                if not res['rows']:
+                    return make_json_response(
+                        success=0,
+                        errormsg=gettext(
+                            'Error: Object not found.'
+                        ),
+                        info=gettext(
+                            'The specified partition could not be found.\n'
+                        )
+                    )
+
+                status, res = super(PartitionsView, self).delete(
+                    gid, sid, did, scid, tid, res)
+
+                if not status:
+                    return internal_server_error(errormsg=res)
+
+            return make_json_response(
+                success=1,
+                info=gettext("Partition dropped")
+            )
 
         except Exception as e:
             return internal_server_error(errormsg=str(e))
