@@ -30,7 +30,10 @@ class TestColumnPropertiesSql(SQLTemplateTestBase):
         self.table_id = cursor.fetchone()[0]
 
     def generate_sql(self, version):
-        template_file = self.get_template_file(version, "properties.sql")
+        file_path = os.path.join(os.path.dirname(__file__), "..", "templates",
+                                 "columns", "sql")
+        template_file = self.get_template_file(version, file_path,
+                                               "properties.sql")
         template = file_as_template(template_file)
         public_schema_id = 2200
         sql = template.render(scid=public_schema_id,
@@ -47,10 +50,3 @@ class TestColumnPropertiesSql(SQLTemplateTestBase):
         self.assertEqual('some_column', first_row['name'])
         self.assertEqual('character varying', first_row['cltype'])
         self.assertEqual(3, len(fetch_result))
-
-    @staticmethod
-    def get_template_file(version, filename):
-        return os.path.join(
-            os.path.dirname(__file__), "..", "templates", "columns", "sql",
-            version, filename
-        )
