@@ -7,6 +7,8 @@
 #
 ##########################################################################
 
+import random
+
 from selenium.webdriver import ActionChains
 from selenium.common.exceptions import TimeoutException
 from regression.python_test_utils import test_utils
@@ -22,6 +24,7 @@ class CheckDebuggerForXssFeatureTest(BaseFeatureTest):
     scenarios = [
         ("Tests to check if Debugger is vulnerable to XSS", dict())
     ]
+    function_name = ""
 
     def before(self):
         with test_utils.Database(self.server) as (connection, _):
@@ -32,12 +35,14 @@ class CheckDebuggerForXssFeatureTest(BaseFeatureTest):
                 )
 
         # Some test function is needed for debugger
+        self.function_name = "a_test_function" + \
+                             str(random.randint(10000, 65535))
         test_utils.create_debug_function(
-            self.server, "postgres", "a_test_function"
+            self.server, "postgres", self.function_name
         )
 
         if test_utils.does_function_exist(self.server, 'postgres',
-                                          'a_test_function') != 'True':
+                                          self.function_name) != 'True':
             raise Exception("The required function is not found")
 
     def runTest(self):
@@ -49,7 +54,7 @@ class CheckDebuggerForXssFeatureTest(BaseFeatureTest):
     def after(self):
         self.page.remove_server(self.server)
         test_utils.drop_debug_function(self.server, "postgres",
-                                       "a_test_function")
+                                       self.function_name)
 
     def _function_node_expandable(self):
         self.page.toggle_open_server(self.server['name'])
@@ -58,7 +63,7 @@ class CheckDebuggerForXssFeatureTest(BaseFeatureTest):
         self.page.toggle_open_tree_item('Schemas')
         self.page.toggle_open_tree_item('public')
         self.page.toggle_open_function_node()
-        self.page.select_tree_item("a_test_function()")
+        self.page.select_tree_item(self.function_name + "()")
 
     def _debug_function(self):
         self.page.driver.find_element_by_link_text("Object").click()
